==> cloud-3.0.0-rc2.tar.gz: cloud/modules/cloud_service_providers/vmware/src/Form/VmwareVmDeleteForm.php <==
<?php

namespace Drupal\vmware\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\vmware\Service\VmwareServiceException;

/**
 * Provides a form for deleting a VM entity.
 *
 * @ingroup vmware
 */
class VmwareVmDeleteForm extends VmwareDeleteForm {

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    $entity = $this->entity;

    return $this->t('Are you sure you want to delete the "@name" VM?', [
      '@name' => $entity->getName(),
    ]);
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\vmware\Service\VmwareServiceException
   *    Thrown when unable to delete entity.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $entity = $this->entity;

    try {
      $this->vmwareService->setCloudContext($entity->getCloudContext());
      $this->vmwareService->login();
      $this->vmwareService->deleteVm([
        'VmId' => $entity->getVmId(),
      ]);

      $entity->delete();

      $this->messenger->addStatus($this->getDeletionMessage());
      $this->logDeletionMessage();
    }
    catch (VmwareServiceException $e) {
      // @todo Possibly refactor processOperationErrorStatus() to add the third parameter for the reason.
      if ($entity->getPowerState() === 'POWERED_ON') {
        $entity_type = $entity->getEntityType();
        $label = $entity->label();
        $message = $this->t('The @type %label could not be @passive_operation since the VM is currently running.', [
          '@type' => $entity_type->getSingularLabel(),
          '%label' => $entity->toLink($label)->toString(),
          '@passive_operation' => 'deleted',
        ]);
        $this->messenger()->addError($message);
        $this->logger('vmware')->error($message);
      }
      else {
        $this->processOperationErrorStatus($entity, 'deleted');
      }
    }

    $form_state->setRedirect('view.vmware_vm.list', ['cloud_context' => $entity->getCloudContext()]);
  }

}

==> cloud-3.2.0.tar.gz: cloud/modules/cloud_service_providers/vmware/src/Form/VmwareVmDeleteForm.php <==
<?php

namespace Drupal\vmware\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\vmware\Service\VmwareServiceException;

/**
 * Provides a form for deleting a VM entity.
 *
 * @ingroup vmware
 */
class VmwareVmDeleteForm extends VmwareDeleteForm {

  /**
   * {@inheritdoc}
   */
  public function getQuestion(): TranslatableMarkup {
    $entity = $this->entity;

    return $this->t('Are you sure you want to delete the "@name" VM?', [
      '@name' => $entity->getName(),
    ]);
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\vmware\Service\VmwareServiceException
   *    Thrown when unable to delete entity.
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $entity = $this->entity;

    try {
      $this->vmwareService->setCloudContext($entity->getCloudContext());
      $this->vmwareService->login();
      $this->vmwareService->deleteVm([
        'VmId' => $entity->getVmId(),
      ]);

      $entity->delete();

      $this->messenger->addStatus($this->getDeletionMessage());
      $this->logDeletionMessage();
    }
    catch (VmwareServiceException $e) {
      // @todo Possibly refactor processOperationErrorStatus() to add the third parameter for the reason.
      if ($entity->getPowerState() === 'POWERED_ON') {
        $entity_type = $entity->getEntityType();
        $label = $entity->label();
        $message = $this->t('The @type %label could not be @passive_operation since the VM is currently running.', [
          '@type' => $entity_type->getSingularLabel(),
          '%label' => $entity->toLink($label)->toString(),
          '@passive_operation' => 'deleted',
        ]);
        $this->messenger()->addError($message);
        $this->logger('vmware')->error($message);
      }
      else {
        $this->processOperationErrorStatus($entity, 'deleted');
      }
    }

    $form_state->setRedirect('view.vmware_vm.list', ['cloud_context' => $entity->getCloudContext()]);
  }

}
